This is unreleased documentation for the main (development) branch of crypto-glue.

AesKwp

Struct AesKwp 

pub struct AesKwp<C> { /* private fields */ }
AES Key Wrapper with Padding (KWP), as defined in RFC 5649.

Implementations

Source

impl<C: BlockCipherEncrypt<BlockSize = U16>> AesKwp<C>

pub fn wrap_key<'a>( &self, key: &[u8], buf: &'a mut [u8], ) -> Result<&'a [u8], Error>

AES Key Wrap with Padding, as defined in RFC 5649.

The buf buffer will be overwritten, and must be the smallest multiple of IV_LEN (i.e. 8) which is at least IV_LEN bytes (i.e. 8 bytes) longer than the length of data.

pub fn wrap_fixed_key<N>( &self, key: &Array<u8, N>, ) -> Array<u8, Prod<Add1<Quot<Sum<N, U7>, IvLen>>, IvLen>>

Wrap fixed-size key key and return wrapped key.

This method is roughly equivalent to:

ⓘ
pub fn wrap_fixed_key<const N: usize>(
    &self,
    key: &[u8; N],
) -> [u8; IV_LEN * (N.div_ceil(IV_LEN) + 1)]
{ ... }

but uses hybrid_array::Array instead of built-in arrays to work around current limitations of the const generics system.

Source

impl<C: BlockCipherDecrypt<BlockSize = U16>> AesKwp<C>

pub fn unwrap_key<'a>( &self, data: &[u8], buf: &'a mut [u8], ) -> Result<&'a [u8], Error>

AES Key Wrap with Padding, as defined in RFC 5649.

The buf buffer will be overwritten, and must be exactly IV_LEN bytes (i.e. 8 bytes) shorter than the length of data. This method returns a slice of out, truncated to the appropriate length by removing the padding.

pub fn unwrap_fixed_key<N>( &self, wkey: &Array<u8, Prod<Add1<Quot<Sum<N, U7>, IvLen>>, IvLen>>, ) -> Result<Array<u8, N>, IntegrityCheckFailed>

Unwrap fixed-size wrapped key wkey and return resulting key.

This method is roughly equivalent to:

ⓘ
pub fn unwrap_fixed_key<const N: usize>(
    &self,
    wkey: &[u8; IV_LEN * (N.div_ceil(IV_LEN) + 1)],
) -> [u8; N]
{ ... }

but uses hybrid_array::Array instead of built-in arrays to work around current limitations of the const generics system.